@@ -10,7 +10,7 @@ test_that("simple optimization", {
   testthat::expect_equal(max(vx$results$t), 10)
   testthat::expect_true(is.na(sd(vx$put)))
 
-  vx <- simRestore::optimize_static(num_generations = 2,
+  vx <- simRestore::optimize_static(num_generations = 5,
                                     target_frequency = 0.5,
                                     optimize_put = FALSE,
                                     optimize_pull = TRUE,
@@ -19,7 +19,7 @@ test_that("simple optimization", {
                                     num_replicates = 1)
 
   testthat::expect_lt(vx$final_freq, 0.999)
-  testthat::expect_equal(max(vx$results$t), 2)
+  testthat::expect_equal(length(vx$results$t), 5)
   testthat::expect_true(is.na(sd(vx$pull)))
 
   vx <- simRestore::optimize_static(num_generations = 20,
